about summary refs log tree commit diff
path: root/src/nm-dispatcher
diff options
context:
space:
mode:
Diffstat (limited to 'src/nm-dispatcher')
-rw-r--r--src/nm-dispatcher/nm-dispatcher-utils.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/nm-dispatcher/nm-dispatcher-utils.c b/src/nm-dispatcher/nm-dispatcher-utils.c
index 74ea4e40..f8a4c280 100644
--- a/src/nm-dispatcher/nm-dispatcher-utils.c
+++ b/src/nm-dispatcher/nm-dispatcher-utils.c
@@ -453,8 +453,12 @@ nm_dispatcher_utils_construct_envp(const char  *action,
 
     items = g_ptr_array_new_with_free_func(g_free);
 
-    /* Hostname and connectivity changes don't require a device nor contain a connection */
-    if (NM_IN_STRSET(action, NMD_ACTION_HOSTNAME, NMD_ACTION_CONNECTIVITY_CHANGE))
+    /* Hostname, dns and connectivity changes don't require a device nor contain
+     * a connection */
+    if (NM_IN_STRSET(action,
+                     NMD_ACTION_HOSTNAME,
+                     NMD_ACTION_CONNECTIVITY_CHANGE,
+                     NMD_ACTION_DNS_CHANGE))
         goto done;
 
     /* Connection properties */